/*
 * Copyright (c) 2018 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

Item {
    
    property string amplitude: '0'
    property string frequency: '1'
    property string velocity: '2'
        
    property double amplitudeDefault: 0
    property double frequencyDefault: 0.000
    property double velocityDefault: 0.00
     
    property var defaultParameters: [amplitude, frequency, velocity]
    
    width: 250
    height: 100
    
    Component.onCompleted: {
        if (filter.isNew) {
            filter.set(amplitude, amplitudeDefault)
            filter.set(frequency, frequencyDefault)
            filter.set(velocity, velocityDefault)
            filter.savePreset(preset.defaultParameters)
        }
            setControls()
    }

    function setControls() {
        amplitudeSlider.value = filter.getDouble(amplitude)
        frequencySlider.value = filter.getDouble(frequency)
        velocitySlider.value = filter.getDouble(velocity)
        
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 3

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: [amplitude, frequency, velocity]
            Layout.columnSpan: 2
            onPresetSelected: setControls()
        }

        Label {
            text: qsTr('Amplitude')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: amplitudeSlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.01
            decimals: 2
            //value: filter.getDouble(amplitude)
            onValueChanged: filter.set(amplitude, value)
        }
        UndoButton {
            onClicked: amplitudeSlider.value = amplitudeDefault
        }

        Label {
            text: qsTr('Frequency')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: frequencySlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.01
            decimals: 2
            //value: filter.getDouble(frequency)
            onValueChanged: filter.set(frequency, value)
            }
        UndoButton {
            onClicked: frequencySlider.value = frequencyDefault
        }

        Label {
            text: qsTr('Velocity')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: velocitySlider
            minimumValue: 0
            maximumValue: 1
			stepSize: 0.01
            decimals: 2
            //value: filter.getDouble(velocity)
            onValueChanged: filter.set(velocity, value)
        }
        UndoButton {
            onClicked: velocitySlider.value = velocityDefault
        }

        
        Item {
            Layout.fillHeight: true;
        }
    }
    // Connections {
       // target: producer
      //  onPositionChanged: setControls()
    // }
  }
